src/openttd.cpp
changeset 6659 9e786755ed61
parent 6658 59048224be55
child 6677 0578c2e31ed1
--- a/src/openttd.cpp	Mon Mar 19 11:27:30 2007 +0000
+++ b/src/openttd.cpp	Mon Mar 19 11:41:21 2007 +0000
@@ -1758,9 +1758,9 @@
 	/* do the same as when elrails were enabled/disabled manually just now */
 	SettingsDisableElrail(_patches.disable_elrails);
 
 	/* From version 52, the map array was changed for house tiles to allow
 	 * space for newhouses grf features. A new byte, m7, was also added. */
-	if (CheckSavegameVersion(52)) {
+	if (CheckSavegameVersion(53)) {
 		for (TileIndex t = 0; t < map_size; t++) {
 			_me[t].m7 = 0;
@@ -1758,9 +1758,9 @@
 	SettingsDisableElrail(_patches.disable_elrails);
 
-	/* From version 52, the map array was changed for house tiles to allow
+	/* From version 53, the map array was changed for house tiles to allow
 	 * space for newhouses grf features. A new byte, m7, was also added. */